@@ -28,19 +28,16 @@
 # If the message is a broadcast message then all instances of the consumer forward that
 # message to all connected parties.
 
-import asyncio
 import json
 
 #
 # Third-party imports
 # -------------------
-import os
 from datetime import datetime
 from typing import Dict, Optional
-from multi_await import multi_await
+from multi_await import multi_await  # type: ignore
 
 import aioredis
-import async_timeout
 
 # Local application imports
 # -------------------------
@@ -49,7 +46,6 @@ from fastapi import (
     Cookie,
     Query,
     WebSocket,  # Depends,; noqa F401
-    WebSocketDisconnect,
     status,
 )
 from fastapi.templating import Jinja2Templates
@@ -147,17 +143,16 @@ async def websocket_endpoint(websocket: WebSocket, uname: str):
     will block
     """
     rslogger.debug(f"IN WEBSOCKET {uname=}")
-    # res = await auth_manager.get_current_user(user)
-    # username = res.username
-    # rslogger.debug(f"{res=}")
     username = uname
+    # local_users is a global/module variable shared by all  requests served
+    # by the same worker process.
     local_users.add(username)
     await manager.connect(username, websocket)
-    r = aioredis.from_url(os.environ.get("REDIS_URI", "redis://localhost:6379/0"))
+    r = aioredis.from_url(settings.redis_uri)
     subscriber = r.pubsub()
 
     async def my_get_message():
-        return await subscriber.get_message(timeout=1.0)
+        return await subscriber.get_message(timeout=1.0, ignore_subscribe_messages=True)
 
     await subscriber.subscribe("peermessages")
 
@@ -196,18 +191,19 @@ async def websocket_endpoint(websocket: WebSocket, uname: str):
                     # the ``data`` field of the redis message
                     data = json.loads(pmess["data"])
                 else:
-                    rslogger.error("unknown message type {pmess['type']}")
+                    rslogger.error(f"unknown message type {pmess['type']}")
                     continue
                 if data["broadcast"]:
                     await manager.broadcast(data)
                 else:
-                    # because **every** connection is in this loop we only
-                    # want to send a non-broadcast message if it is to
-                    # ourself.
+                    # because **every** connection runs this same loop
+                    # we only want to send a non-broadcast message if
+                    # it is to ourself.
                     partner = await r.hget("partnerdb", data["from"])
                     partner = partner.decode("utf8")
                     if partner == username:
                         await manager.send_personal_message(partner, data)
+                        # log the message
                         await create_useinfo_entry(
                             UseinfoValidation(
                                 event="sendmessage",
@@ -224,9 +220,13 @@ async def websocket_endpoint(websocket: WebSocket, uname: str):
                 rslogger.debug(
                     f"We don't expect in coming websock messages but got: {wsres}"
                 )
+                # TODO: now that we have multi-await working it *may* be more
+                # efficient to go back to sending all peer messages by websocket
+                # and putting them into the subscriber queue here rather than
+                # having a separate endpoint.
 
 
 @router.post("/send_message")
 async def send_message(packet: PeerMessage):
-    r = await aioredis.from_url(os.environ.get("REDIS_URI", "redis://localhost:6379/0"))
+    r = await aioredis.from_url(settings.redis_uri)
     r.publish("peermessages", packet.json())
